#[repr(transparent)]pub struct AvatarImage {
inner: TypedObjectRef<AvatarImage, ()>,
phantom: PhantomData<()>,
}Expand description
The image data for an avatar.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<AvatarImage, ()>phantom: PhantomData<()>Implementations
Sourceimpl AvatarImage
impl AvatarImage
Sourcepub fn uri_string(&self) -> <PhantomData<Option<String>> as Property>::Value
pub fn uri_string(&self) -> <PhantomData<Option<String>> as Property>::Value
The Matrix URI of the AvatarImage, as a string.
Sourcepub fn uri_source(&self) -> <Cell<AvatarUriSource> as Property>::Value
pub fn uri_source(&self) -> <Cell<AvatarUriSource> as Property>::Value
The source of the URI avatar.
Sourcepub fn scale_factor(&self) -> <Cell<u32> as Property>::Value
pub fn scale_factor(&self) -> <Cell<u32> as Property>::Value
The scale factor to use to load the cached paintable.
Sourcepub fn set_scale_factor<'a>(
&self,
value: impl Borrow<<<Cell<u32> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_scale_factor<'a>( &self, value: impl Borrow<<<Cell<u32> as Property>::Value as HasParamSpec>::SetValue>, )
The scale factor to use to load the cached paintable.
Sourcepub fn small_paintable(&self) -> <RefCell<Option<Paintable>> as Property>::Value
pub fn small_paintable(&self) -> <RefCell<Option<Paintable>> as Property>::Value
The cached paintable of the avatar at small size, if any.
Sourcepub fn big_paintable(&self) -> <RefCell<Option<Paintable>> as Property>::Value
pub fn big_paintable(&self) -> <RefCell<Option<Paintable>> as Property>::Value
The cached paintable of the avatar at big size, if any.
Sourcepub fn connect_session_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session property
Sourcepub fn connect_uri_string_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_uri_string_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the uri-string property
Sourcepub fn connect_uri_source_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_uri_source_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the uri-source property
Sourcepub fn connect_scale_factor_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_scale_factor_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the scale-factor property
Sourcepub fn connect_small_paintable_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_small_paintable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the small-paintable property
Sourcepub fn connect_big_paintable_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_big_paintable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the big-paintable property
Sourcepub fn notify_session(&self)
pub fn notify_session(&self)
Notify listeners of a change in the session property
Sourcepub fn notify_uri_string(&self)
pub fn notify_uri_string(&self)
Notify listeners of a change in the uri-string property
Sourcepub fn notify_uri_source(&self)
pub fn notify_uri_source(&self)
Notify listeners of a change in the uri-source property
Sourcepub fn notify_scale_factor(&self)
pub fn notify_scale_factor(&self)
Notify listeners of a change in the scale-factor property
Sourcepub fn notify_small_paintable(&self)
pub fn notify_small_paintable(&self)
Notify listeners of a change in the small-paintable property
Sourcepub fn notify_big_paintable(&self)
pub fn notify_big_paintable(&self)
Notify listeners of a change in the big-paintable property
Sourceimpl AvatarImage
impl AvatarImage
Sourcepub(crate) const SMALL_PAINTABLE_SIZE: u32 = 48
pub(crate) const SMALL_PAINTABLE_SIZE: u32 = 48
The small size of the paintable.
This is usually the size presented in the timeline or the sidebar. This is also the size of the avatar in GNOME Shell notifications.
This matches an avatar of size 48 or smaller. This size is cached
indefinitely after the first AvatarImage::small_paintable_ref() is
taken.
Sourcepub(crate) const BIG_PAINTABLE_SIZE: u32 = 150
pub(crate) const BIG_PAINTABLE_SIZE: u32 = 150
The big size of the paintable.
This is usually the size presented in the room details or user profile.
This matches an avatar of size 150 or smaller. This is only cached
when at least one AvatarImage::big_paintable_ref() is held.
Sourcepub(crate) fn new(
session: &Session,
uri_source: AvatarUriSource,
uri: Option<OwnedMxcUri>,
info: Option<ImageInfo>,
) -> Self
pub(crate) fn new( session: &Session, uri_source: AvatarUriSource, uri: Option<OwnedMxcUri>, info: Option<ImageInfo>, ) -> Self
Construct a new AvatarImage with the given session, Matrix URI and
avatar info.
Sourcepub(crate) fn set_uri_and_info(
&self,
uri: Option<OwnedMxcUri>,
info: Option<ImageInfo>,
)
pub(crate) fn set_uri_and_info( &self, uri: Option<OwnedMxcUri>, info: Option<ImageInfo>, )
Set the Matrix URI and information of the avatar.
Sourcepub(crate) fn small_paintable_ref(&self) -> CountedRef
pub(crate) fn small_paintable_ref(&self) -> CountedRef
Get a small paintable ref.
Sourcepub(crate) fn big_paintable_ref(&self) -> CountedRef
pub(crate) fn big_paintable_ref(&self) -> CountedRef
Get a big paintable ref.
Sourcepub(crate) async fn load_small_paintable(
&self,
) -> Result<Option<Paintable>, ImageError>
pub(crate) async fn load_small_paintable( &self, ) -> Result<Option<Paintable>, ImageError>
Get the small paintable.
We first try to get it from the cache, and load it if it is not cached.
Sourcepub(crate) fn error(&self) -> Option<ImageError>
pub(crate) fn error(&self) -> Option<ImageError>
The last error encountered when loading the paintable of the avatar, if any.
Sourcepub fn connect_error_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_error_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when the error changed.